The highest tagged major version is
v2 .
Discover Packages
github.com/RUSEGAL/ruseon-core
pkg
eventbus
package
Version:
v1.4.0
Opens a new window with list of versions in this module.
Published: Aug 13, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Bus interface {
Publish(topic string , cameraID string , data any )
Stop()
}
New создает новую шину событий и запускает воркеры.
type Event struct {
ID string `json:"id"`
TimestampMs int64 `json:"timestamp_ms"`
Topic string `json:"topic"`
CameraID string `json:"camera_id,omitempty"`
Data any `json:"data,omitempty"`
}
Event представляет единицу события в системе
Source Files
¶
Click to show internal directories.
Click to hide internal directories.